<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>KWin::MultitaskViewEffect</name>
    <message>
        <source>Drag upwards to remove</source>
        <translation>Për ta hequr, tërhiqeni për sipër</translation>
    </message>
    <message>
        <source>No windows</source>
        <translation>Pa dritare</translation>
    </message>
</context>
</TS>